import unittest
from unittest import TestCase
from clouddrift import timeseries

if __name__ == "__main__":
    unittest.main()


class timeseries_tests(TestCase):
    def test_example(self):
        pass
